import { CancelError, HTTPError, Options, Response } from 'got';
export interface Logger {
    info(...args: unknown[]): void;
    error(...args: unknown[]): void;
    debug(...args: unknown[]): void;
}
export interface HttpLogger {
    logSuccess(response: Response, options: Options): void;
    logFailure(error: HTTPError | CancelError): void;
}
export declare class NoOpLogger implements HttpLogger {
    logSuccess(_response: Response, _options: Options): void;
    logFailure(_error: HTTPError | CancelError): void;
}
export declare class GenericLogger implements HttpLogger {
    #private;
    constructor(logger: Logger);
    logSuccess(response: Response, options: Options): void;
    logFailure(error: HTTPError | CancelError): void;
}
export declare class PinoLogger implements HttpLogger {
    #private;
    constructor(logger: Logger);
    logSuccess(res: Response): void;
    logFailure(error: HTTPError | CancelError): void;
}
export declare const redact: (options: Options) => Options;
export declare const redactSensitiveHeaders: (options: Options) => void;
export declare const redactSensitiveProps: (options: Options) => void;
